@@ -12,8 +12,8 @@ sys.path.append(os.path.dirname(__file__))
 import jieba.posseg as pseg
 import numpy as np
 from tqdm import tqdm
-from utils import get_stop_words
-from word_embedding import word_vector
+from .utils import get_stop_words
+from .word_embedding import word_vector
 
 def sentence_vector(model, sentence, add_pos_weight=['n','nr','ng','ns','nt','nz'],stop_words_path=None):
     words = pseg.cut(sentence)
